@@ -7,7 +7,6 @@ dev_file <- suppressMessages(add_flat_template(pkg = dummypackage, overwrite = T
 flat_file <- dev_file[grepl("flat_", dev_file)]
 
 usethis::with_project(dummypackage, {
-
   test_that("load_flat_functions works", {
     expect_true(inherits(load_flat_functions, "function"))
 
@@ -15,7 +14,8 @@ usethis::with_project(dummypackage, {
     testenv <- new.env()
     expect_message(
       load_flat_functions(flat_file = flat_file, envir = testenv),
-      "sourced in global env")
+      "sourced in global env"
+    )
 
     expect_true(inherits(testenv$my_median, "function"))
     expect_true(inherits(testenv$my_other_median, "function"))
